==> nextcloud-14.0.4.tar.bz2: nextcloud/apps/dav/l10n/he.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "יומן",
    "Todos" : "משימות מטלות",
    "Personal" : "אישי",
    "{actor} created calendar {calendar}" : "היומן {calendar} נוצר על ידי {actor}",
    "You created calendar {calendar}" : "מחקת את היומן {calendar}",
    "{actor} deleted calendar {calendar}" : "היומן {calendar} נמחק על ידי {actor}",
    "You deleted calendar {calendar}" : "מחקת את היומן {calendar}",
    "{actor} updated calendar {calendar}" : "היומן {calendar} עודכן על ידי {actor}",
    "You updated calendar {calendar}" : "עדכנת את היומן {calendar}",
    "You shared calendar {calendar} as public link" : "שיתפת את היומן {calendar} כקישור ציבורי",
    "You removed public link for calendar {calendar}" : "הסרת את הקישור הציבורי ליומן {calendar}",
    "{actor} shared calendar {calendar} with you" : "שותף אתך לוח השנה {calendar} על ידי {actor}",
    "You shared calendar {calendar} with {user}" : "שיתפת לוח שנה {calendar} עם {user}",
    "{actor} shared calendar {calendar} with {user}" : "לוח השנה {calendar} שותף על ידי {actor} עם {user}",
    "{actor} unshared calendar {calendar} from you" : "השיתוף של לוח השנה {calendar} אתך הופסק על ידי {actor}",
    "You unshared calendar {calendar} from {user}" : "ביטלת את שיתוף לוח השנה {calendar} עם {user}",
    "{actor} unshared calendar {calendar} from {user}" : "השיתוף של לוח השנה {calendar} עם {user} הופסק על ידי {actor}",
    "{actor} unshared calendar {calendar} from themselves" : "השיתוף של לוח השנה {calendar} עם עצמם הופסק על ידי {actor}",
    "You shared calendar {calendar} with group {group}" : "שיתפת את לוח השנה {calendar} עם הקבוצה {group}",
    "{actor} shared calendar {calendar} with group {group}" : "לוח השנה {calendar} שותף עם הקבוצה {group} על ידי {actor}",
    "You unshared calendar {calendar} from group {group}" : "הפסקת את שיתוף לוח השנה {calendar} עם הקבוצה {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "השיתוף של לוח השנה {calendar} עם {group} הופסק על ידי {actor}",
    "{actor} created event {event} in calendar {calendar}" : "האירוע {event} נוצר בלוח השנה {calendar} על ידי {actor}",
    "You created event {event} in calendar {calendar}" : "יצרת אירוע {event} בלוח השנה {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "האירוע {event} נמחק מלוח השנה {calendar} על ידי {actor}",
    "You deleted event {event} from calendar {calendar}" : "מחקת אירוע {event} מלוח השנה {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "האירוע {event} עודכן בלוח השנה {calendar} על ידי {actor}",
    "You updated event {event} in calendar {calendar}" : "עדכנת את האירוע {event} בלוח השנה {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "המשימה לביצוע {todo} ברשימה {calendar} נוצרה על ידי {actor}",
    "You created todo {todo} in list {calendar}" : "יצרת את המשימה לביצוע {todo} ברשימה {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "המשימה לביצוע {todo} מהרשימה {calendar} נמחקה על ידי {actor}",
    "You deleted todo {todo} from list {calendar}" : "מחקת את המשימה לביצוע {todo} מהרשימה {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "המשימה לביצוע {todo} ברשימה {calendar} עודכנה על ידי {actor}",
    "You updated todo {todo} in list {calendar}" : "עדכנת את המשימה לביצוע {todo} ברשימה {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "המשימה לביצוע {todo} ברשימה {calendar} נפתרה על ידי {actor}",
    "You solved todo {todo} in list {calendar}" : "פתרת משימה לביצוע {todo} ברשימה {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "המשימה לביצוע {todo} ברשימה {calendar} נפתחה מחדש על ידי {actor}",
    "You reopened todo {todo} in list {calendar}" : "פתחת מחדש את המשימה לביצוע {todo} ברשימה {calendar}",
    "A <strong>calendar</strong> was modified" : " <strong>יומן</strong> נערך",
    "A calendar <strong>event</strong> was modified" : "<strong>אירוע</strong> ביומן נערך",
    "A calendar <strong>todo</strong> was modified" : "נערכה <strong>מטלה</strong> בלוח שנה",
    "Contact birthdays" : "ימי הולדת של אנשי קשר",
    "Invitation canceled" : "ההזמנה בוטלה",
    "Hello %s," : "שלום %s,",
    "Invitation updated" : "ההזמנה עודכנה",
    "When:" : "מתי:",
    "Where:" : "איפה:",
    "Description:" : "תיאור:",
    "Link:" : "קישור:",
    "Accept" : "קבלה",
    "Decline" : "דחייה",
    "More options at %s" : "אפשרויות נוספים ב־%s",
    "Contacts" : "אנשי קשר",
    "WebDAV" : "WebDAV",
    "Technical details" : "פרטים טכניים",
    "Remote Address: %s" : "כתובת מרוחקת: %s",
    "Request ID: %s" : "מזהה בקשה: %s",
    "There was an error updating your attendance status." : "אירעה שגיאה בעת עדכון מצב ההשתתפות שלך.",
    "Please contact the organizer directly." : "נא ליצור קשר עם הגוף מארגן ישירות.",
    "Are you accepting the invitation?" : "האם להיענות להזמנה?",
    "Tentative" : "טנטטיבית",
    "Save" : "שמירה",
    "Your attendance was updated successfully." : "ההשתתפות שלך עודכנה בהצלחה.",
    "Send invitations to attendees" : "שליחת הזמנות למשתתפים",
    "Please make sure to properly set up the email settings above." : "נא לוודא שהגדרת את הדוא״ל שלהלן כראוי.",
    "Automatically generate a birthday calendar" : "יצירת יומן ימי הולדת אוטומטית",
    "Birthday calendars will be generated by a background job." : "יומני ימי הולדת ייווצרו על ידי משימה ברקע.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "לכן הם לא יהיה זמינים מיד לאחר ההפעלה אלא הם יופיעו לאחר זמן מה.",
    "%s via %s" : "%s דרך %s",
    "The meeting »%s« with %s was canceled." : "הפגישה „%s” עם %s בוטלה.",
    "The meeting »%s« with %s was updated." : "הפגישה „%s” עם %s עודכנה.",
    "CalDAV server" : "שרת CalDAV"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-20.0.9.tar.bz2: nextcloud/apps/dav/l10n/he.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "יומן",
    "Todos" : "משימות מטלות",
    "Personal" : "אישי",
    "{actor} created calendar {calendar}" : "היומן {calendar} נוצר על ידי {actor}",
    "You created calendar {calendar}" : "מחקת את היומן {calendar}",
    "{actor} deleted calendar {calendar}" : "היומן {calendar} נמחק על ידי {actor}",
    "You deleted calendar {calendar}" : "מחקת את היומן {calendar}",
    "{actor} updated calendar {calendar}" : "היומן {calendar} עודכן על ידי {actor}",
    "You updated calendar {calendar}" : "עדכנת את היומן {calendar}",
    "You shared calendar {calendar} as public link" : "שיתפת את היומן {calendar} כקישור ציבורי",
    "You removed public link for calendar {calendar}" : "הסרת את הקישור הציבורי ליומן {calendar}",
    "{actor} shared calendar {calendar} with you" : "שותף אתך לוח השנה {calendar} על ידי {actor}",
    "You shared calendar {calendar} with {user}" : "שיתפת לוח שנה {calendar} עם {user}",
    "{actor} shared calendar {calendar} with {user}" : "לוח השנה {calendar} שותף על ידי {actor} עם {user}",
    "{actor} unshared calendar {calendar} from you" : "השיתוף של לוח השנה {calendar} אתך הופסק על ידי {actor}",
    "You unshared calendar {calendar} from {user}" : "ביטלת את שיתוף לוח השנה {calendar} עם {user}",
    "{actor} unshared calendar {calendar} from {user}" : "השיתוף של לוח השנה {calendar} עם {user} הופסק על ידי {actor}",
    "{actor} unshared calendar {calendar} from themselves" : "השיתוף של לוח השנה {calendar} עם עצמם הופסק על ידי {actor}",
    "You shared calendar {calendar} with group {group}" : "שיתפת את לוח השנה {calendar} עם הקבוצה {group}",
    "{actor} shared calendar {calendar} with group {group}" : "לוח השנה {calendar} שותף עם הקבוצה {group} על ידי {actor}",
    "You unshared calendar {calendar} from group {group}" : "הפסקת את שיתוף לוח השנה {calendar} עם הקבוצה {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "השיתוף של לוח השנה {calendar} עם {group} הופסק על ידי {actor}",
    "{actor} created event {event} in calendar {calendar}" : "האירוע {event} נוצר בלוח השנה {calendar} על ידי {actor}",
    "You created event {event} in calendar {calendar}" : "יצרת אירוע {event} בלוח השנה {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "האירוע {event} נמחק מלוח השנה {calendar} על ידי {actor}",
    "You deleted event {event} from calendar {calendar}" : "מחקת אירוע {event} מלוח השנה {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "האירוע {event} עודכן בלוח השנה {calendar} על ידי {actor}",
    "You updated event {event} in calendar {calendar}" : "עדכנת את האירוע {event} בלוח השנה {calendar}",
    "Busy" : "עסוק",
    "{actor} created todo {todo} in list {calendar}" : "המשימה לביצוע {todo} ברשימה {calendar} נוצרה על ידי {actor}",
    "You created todo {todo} in list {calendar}" : "יצרת את המשימה לביצוע {todo} ברשימה {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "המשימה לביצוע {todo} מהרשימה {calendar} נמחקה על ידי {actor}",
    "You deleted todo {todo} from list {calendar}" : "מחקת את המשימה לביצוע {todo} מהרשימה {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "המשימה לביצוע {todo} ברשימה {calendar} עודכנה על ידי {actor}",
    "You updated todo {todo} in list {calendar}" : "עדכנת את המשימה לביצוע {todo} ברשימה {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "המשימה לביצוע {todo} ברשימה {calendar} נפתרה על ידי {actor}",
    "You solved todo {todo} in list {calendar}" : "פתרת משימה לביצוע {todo} ברשימה {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "המשימה לביצוע {todo} ברשימה {calendar} נפתחה מחדש על ידי {actor}",
    "You reopened todo {todo} in list {calendar}" : "פתחת מחדש את המשימה לביצוע {todo} ברשימה {calendar}",
    "Calendar and tasks" : "לוח שנה ומשימות",
    "A <strong>calendar</strong> was modified" : " <strong>יומן</strong> נערך",
    "A calendar <strong>event</strong> was modified" : "<strong>אירוע</strong> ביומן נערך",
    "A calendar <strong>todo</strong> was modified" : "נערכה <strong>מטלה</strong> בלוח שנה",
    "Contact birthdays" : "ימי הולדת של אנשי קשר",
    "Death of %s" : "הפטירה של %s",
    "Calendar:" : "לוח שנה:",
    "Date:" : "תאריך:",
    "Where:" : "איפה:",
    "Description:" : "תיאור:",
    "Untitled event" : "אירוע ללא כותרת",
    "_%n year_::_%n years_" : ["שנה","שנתיים","%n שנים","%n שנים"],
    "_%n month_::_%n months_" : ["חודש","חודשיים","%n חודשים","%n חודשים"],
    "_%n day_::_%n days_" : ["יום","יומיים","%n ימים","%n ימים"],
    "_%n hour_::_%n hours_" : ["שעה","שעתיים","%n שעות","%n שעות"],
    "_%n minute_::_%n minutes_" : ["דקה","%n דקות","%n דקות","%n דקות"],
    "%s (in %s)" : "%s (בתוך %s)",
    "%s (%s ago)" : "%s (לפני %s)",
    "Calendar: %s" : "לוח שנה: %s",
    "Date: %s" : "תאריך: %s",
    "Description: %s" : "תיאור: %s",
    "Where: %s" : "איפה: %s",
    "%1$s via %2$s" : "%1$s דרך %2$s",
    "Invitation canceled" : "ההזמנה בוטלה",
    "Invitation updated" : "ההזמנה עודכנה",
    "Invitation" : "הזמנה",
    "Title:" : "כותרת:",
    "Time:" : "שעה:",
    "Location:" : "מיקום:",
    "Link:" : "קישור:",
    "Organizer:" : "ארגון:",
    "Attendees:" : "משתתפים:",
    "Accept" : "קבלה",
    "Decline" : "דחייה",
    "More options …" : "אפשרויות נוספות…",
    "More options at %s" : "אפשרויות נוספים ב־%s",
    "Contacts" : "אנשי קשר",
    "System in maintenance mode." : "המערכת במצב עבודות תחזוקה.",
    "Upgrade needed" : "נדרש עדכון",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "עליך להגדיר את ה־%s שלך להשתמש ב־HTTPS כדי להשתמש ב־CalDAV וב־CardDAV עם iOS/macOS.",
    "Configures a CalDAV account" : "מגדיר חשבון CalDAV",
    "Configures a CardDAV account" : "מגדיר חשבון CardDAV",
    "Events" : "אירועים",
    "Tasks" : "משימות",
    "Untitled task" : "משימה ללא כותרת",
    "Completed on %s" : "הושלמה ב־%s",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "נקודת קצה WebDAV",
    "There was an error updating your attendance status." : "אירעה שגיאה בעת עדכון מצב ההשתתפות שלך.",
    "Please contact the organizer directly." : "נא ליצור קשר עם הגוף מארגן ישירות.",
    "Are you accepting the invitation?" : "האם להיענות להזמנה?",
    "Tentative" : "טנטטיבית",
    "Save" : "שמירה",
    "Your attendance was updated successfully." : "ההשתתפות שלך עודכנה בהצלחה.",
    "Calendar server" : "שרת לוח שנה",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "עליך גם להתקין את {calendarappstoreopen}יישומון לוח שנה{linkclose}, או {calendardocopen}לחבר את שולחן העבודה והמכשיר הנייד שלך לסנכרון ↖{linkclose}.",
    "Send invitations to attendees" : "שליחת הזמנות למשתתפים",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "נא לוודא שהגדרת את {emailopen}שרת הדוא״ל{linkclose} כראוי.",
    "Automatically generate a birthday calendar" : "יצירת יומן ימי הולדת אוטומטית",
    "Birthday calendars will be generated by a background job." : "יומני ימי הולדת ייווצרו על ידי משימה ברקע.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "לכן הם לא יהיה זמינים מיד לאחר ההפעלה אלא הם יופיעו לאחר זמן מה.",
    "Send notifications for events" : "שליחת התראות לאירועים",
    "Notifications are sent via background jobs, so these must occur often enough." : "התראות נשלחות באמצעות משימות רקע, לכן הבדיקה תתבצע יחסית לעתים קרובות.",
    "Enable notifications for events via push" : "הפעלת התראות לאירועים בדחיפה",
    "Hello %s," : "שלום %s,",
    "The meeting »%1$s« with %2$s was canceled." : "הפגישה »%1$s« עם %2$s בוטלה.",
    "The meeting »%1$s« with %2$s was updated." : "הפגישה »%1$s« עם %2$s עודכנה.",
    "%1$s invited you to »%2$s«" : "הוזמנת על ידי %1$s אל „%2$s”",
    "When:" : "מתי:"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
